StringBody

Struct StringBody 

pub struct StringBody { /* private fields */ }
Extractor for reading the request body as a plain UTF-8 string.

Example

use foxtive_ntex::http::extractors::StringBody;

async fn handler(body: StringBody) -> String {
    format!("Received: {}", body.body())
}

Implementations

Source

impl StringBody

pub fn body(&self) -> &String

Returns a reference to the underlying string body.

pub fn into_body(self) -> String

Consumes the StringBody, returning the inner string.

pub fn len(&self) -> usize

Returns the length of the string body in bytes.

pub fn is_empty(&self) -> bool

Returns true if the string body is empty.

pub fn parse<T: FromStr>(&self) -> AppResult<T>
where <T as FromStr>::Err: ToString,

Tries to parse the body to a specific type that implements FromStr. Returns an application-level result or an error if parsing fails.